import 'package:mmoo_base/dao/base_dao.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base_video/entity/video_entity.dart';

import 'video_url.dart';

class VideoDao {
  ///匹配成功开始
  static Future<DataResult> matchSuccess(
      anchorId, callId, channelId, costInfo) async {
    Map other = {
      'userId': anchorId,
      'callId': callId,
      'houseId': channelId,
      'costInfo': costInfo
    };
    var res = await BaseDao.fromBaseJson(other, VideoUrl.matchSuccess());
    if (res.result) {
      var entity = VideoEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///通话开始
  static Future<DataResult> callStart(anchorId, call, callId) async {
    Map other = {'userId': anchorId, 'callId': callId, 'caller': call ? 0 : 1};
    var res = await BaseDao.fromBaseEncrypt(other, VideoUrl.callStart());
    if (res.result) {
      var entity = VideoEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///通话心跳
  static Future<DataResult> calling(callId) async {
    Map other = {'callId': callId};
    var res = await BaseDao.fromBaseEncrypt(other, VideoUrl.calling());
    if (res.result) {
      var entity = VideoEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///通话结束
  static Future<DataResult> callEnd(userId, callId, time, dropped) async {
    Map other = {
      'userId': userId,
      'time': time,
      'status': dropped != 1 ? dropped : '',
      'callId': callId
    };
    var res = await BaseDao.fromBaseEncrypt(other, VideoUrl.callEnd());
    if (res.result) {
      var entity = VideoEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///通话上报
  static Future<DataResult> callFail(userId, callId, type, {net}) async {
    Map other = {
      'userId': userId,
      'callId': callId,
      'type': type,
      'network': net
    };
    var res = await BaseDao.fromBaseEncrypt(other, VideoUrl.callFail());
    if (res.result) {
      var entity = VideoEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }
}
